@@ -21,6 +21,7 @@
  *
  */
  
+#include <sys/types.h> 
 #include <string.h>
 #include <iconv.h>
 #include <stdio.h>
@@ -30,6 +31,7 @@
 #include <errno.h>
 #include <libxml/HTMLparser.h>
 #include <langinfo.h>
+/*#include <md5.h>*/
 
 #include "os-support.h"
 
@@ -48,8 +50,8 @@
 #include "interface.h"
 #include "ui-support.h"
 #include "setup.h"
-#include "md5.h"
 #include "digcalc.h"
+#include "md5.h"
 
 extern struct entity *first_entity;
 
@@ -63,17 +65,24 @@ char * iconvert (char * inbuf) {
 	iconv_t cd;							/* Iconvs conversion descriptor. */
 	char *outbuf, *outbuf_first;		/* We need two pointers so we do not lose
 	                                      the string starting position. */
+	char target_charset[64];
 	size_t inbytesleft, outbytesleft;
 
+	/*(void)strlcpy(target_charset, nl_langinfo(CODESET), sizeof(target_charset));*/
+	strncpy(target_charset, nl_langinfo(CODESET), sizeof(target_charset));
+
 	/* Take a shortcut. */
-	if (strcasecmp (TARGET_CHARSET, "UTF-8") == 0)
+	if (strcasecmp (target_charset, "UTF-8") == 0)
 		return strdup(inbuf);
 	
 	inbytesleft = strlen(inbuf);
 	outbytesleft = strlen(inbuf);
 
+	/*(void)strlcat(target_charset, "//TRANSLIT", sizeof(target_charset));*/
+	strncat(target_charset, "//TRANSLIT", sizeof(target_charset));
+
 	/* cd = iconv_open(nl_langinfo(CODESET), "UTF-8"); */
-	cd = iconv_open (TARGET_CHARSET, "UTF-8");
+	cd = iconv_open (target_charset, "UTF-8");
 	if (cd == (iconv_t) -1) {
 		return NULL;
 	}
